package org.ow2.opensuit.samples.movies_db.model.dataaccess;


import java.util.ArrayList;
import java.util.List;

/**
 * Se comporte comme le string tokenizer Java � l'exception qu'il n'ignore pas
 * les tokens vides.<br>
 * Exemple:
 * 	<code>new StringTokenizer(";a;;bb;ccc;", ";") --> ["a", "bb", "ccc"]</code><br>
 * 	<code>new ExactStringTokenizer(";a;;bb;ccc;", ";") --> ["", "a", "", "bb", "ccc", ""]</code>
 */
class ExactStringTokenizer
{
	private static String[] STRING_ARRAY = {};
	
	public static String[] split(String iString, char delim)
	{
		List<String> ret = new ArrayList<String>();
		ExactStringTokenizer st = new ExactStringTokenizer(iString, delim);
		
		while(st.hasMoreTokens()){
			ret.add(st.nextToken());
		}
		
		return ret.toArray(STRING_ARRAY);
	}
	
	private String str;
	private int curTokenPos;
	private int nextDelimPos;
	private char delim;
	
	public ExactStringTokenizer(String iString, char delim)
	{
		str = iString;
		this.delim = delim;
		reinit();
	}
	private void reinit()
	{
		curTokenPos=0;
		nextDelimPos = Integer.MIN_VALUE;
	}
	public boolean hasMoreTokens()
	{
		if(nextDelimPos == Integer.MIN_VALUE){
			nextDelimPos = str.indexOf(this.delim, curTokenPos);
		}
		
		return nextDelimPos >= 0 || curTokenPos <= str.length();
	}
	public String nextToken()
	{
		if(!hasMoreTokens()){
			return null;
		}
		
		String ret = null;
		if(nextDelimPos >= 0)
		{
			ret = str.substring(curTokenPos, nextDelimPos);
			curTokenPos = nextDelimPos + 1;
			nextDelimPos = Integer.MIN_VALUE;
		}
		else
		{
			// --- end of string
			ret = str.substring(curTokenPos);
			curTokenPos = str.length()+1;
		}
		return ret;
	}
}
